@@ -118,12 +118,21 @@ def list_image_files(
 ) -> List[Path]:
     if base_files is not None:
         return _list_related_files(base_files, img_dir, ".tiff")
-    return sorted(Path(img_dir).rglob("*.tiff"))
+    return sorted(Path(img_dir).rglob("[!.]*.tiff"))
 
 
 def _fix_image_shape(img_file: Union[str, PathLike], img: np.ndarray) -> np.ndarray:
     if img.ndim == 2:
         img = img[np.newaxis, :, :]
+    elif img.ndim == 4:
+        if img.shape[-1] == 1:
+            img = img[:, :, :, 0]
+        elif img.shape[0] == 1:
+            img = img[0, :, :, :]
+        else:
+            raise SteinbockIOException(
+                f"{img_file}: unsupported four-dimensional shape {img.shape}"
+            )
     elif img.ndim == 5:
         size_t, size_z, size_c, size_y, size_x = img.shape
         if size_t != 1 or size_z != 1:
@@ -183,7 +192,7 @@ def write_image(
     tifffile.imwrite(
         img_file,
         data=img[np.newaxis, np.newaxis, :, :, :, np.newaxis],
-        imagej=True,
+        imagej=img.dtype in (np.uint8, np.uint16, np.float32),
     )
 
 
@@ -230,11 +239,31 @@ def list_mask_files(
 ) -> List[Path]:
     if base_files is not None:
         return _list_related_files(base_files, mask_dir, ".tiff")
-    return sorted(Path(mask_dir).rglob("*.tiff"))
+    return sorted(Path(mask_dir).rglob("[!.]*.tiff"))
 
 
 def _fix_mask_shape(mask_file: Union[str, PathLike], mask: np.ndarray) -> np.ndarray:
-    if mask.ndim == 5:
+    if mask.ndim == 3:
+        if mask.shape[0] == 1:
+            mask = mask[0, :, :]
+        elif mask.shape[-1] == 1:
+            mask = mask[:, :, 0]
+        else:
+            raise SteinbockIOException(
+                f"{mask_file}: unsupported three-dimensional shape {mask.shape}"
+            )
+    elif mask.ndim == 4:
+        if mask.shape[0] == 1 and mask.shape[1] == 1:
+            mask = mask[0, 0, :, :]
+        elif mask.shape[0] == 1 and mask.shape[-1] == 1:
+            mask = mask[0, :, :, 0]
+        elif mask.shape[-1] == 1 and mask.shape[-2] == 1:
+            mask = mask[:, :, 0, 0]
+        else:
+            raise SteinbockIOException(
+                f"{mask_file}: unsupported four-dimensional shape {mask.shape}"
+            )
+    elif mask.ndim == 5:
         size_t, size_z, size_c, size_y, size_x = mask.shape
         if size_t != 1 or size_z != 1 or size_c != 1:
             raise SteinbockIOException(
@@ -293,7 +322,7 @@ def write_mask(
     tifffile.imwrite(
         mask_file,
         data=mask[np.newaxis, np.newaxis, np.newaxis, :, :, np.newaxis],
-        imagej=True,
+        imagej=mask.dtype in (np.uint8, np.uint16, np.float32),
     )
 
 
@@ -303,7 +332,7 @@ def list_data_files(
 ) -> List[Path]:
     if base_files is not None:
         return _list_related_files(base_files, data_dir, ".csv")
-    return sorted(Path(data_dir).rglob("*.csv"))
+    return sorted(Path(data_dir).rglob("[!.]*.csv"))
 
 
 def read_data(data_file: Union[str, PathLike]) -> pd.DataFrame:
@@ -321,7 +350,7 @@ def list_neighbors_files(
 ) -> List[Path]:
     if base_files is not None:
         return _list_related_files(base_files, neighbors_dir, ".csv")
-    return sorted(Path(neighbors_dir).rglob("*.csv"))
+    return sorted(Path(neighbors_dir).rglob("[!.]*.csv"))
 
 
 def read_neighbors(neighbors_file: Union[str, PathLike]) -> pd.DataFrame:
