@@ -1,21 +1,17 @@
 import subprocess
-
+from importlib import resources
 from os import PathLike
 from pathlib import Path
 from typing import Union
 
 from ..._env import run_captured
-
-_measurement_pipeline_file_template = (
-    Path(__file__).parent / "data" / "cell_measurement.cppipe"
-)
+from . import data as cellprofiler_data
 
 
 def create_and_save_measurement_pipeline(
     measurement_pipeline_file: Union[str, PathLike], num_channels: int
 ) -> None:
-    with _measurement_pipeline_file_template.open(mode="r") as f:
-        s = f.read()
+    s = resources.read_text(cellprofiler_data, "cell_measurement.cppipe")
     s = s.replace("{{NUM_CHANNELS}}", str(num_channels))
     with Path(measurement_pipeline_file).open(mode="w") as f:
         f.write(s)
